cardspecialcolor

package
v0.0.0-...-18f4101 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 3, 2024 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the cardspecialcolor type in the database.
	Label = "card_special_color"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldKey holds the string denoting the key field in the database.
	FieldKey = "key"
	// FieldNameJa holds the string denoting the name_ja field in the database.
	FieldNameJa = "name_ja"
	// FieldNameEn holds the string denoting the name_en field in the database.
	FieldNameEn = "name_en"
	// EdgeCards holds the string denoting the cards edge name in mutations.
	EdgeCards = "cards"
	// Table holds the table name of the cardspecialcolor in the database.
	Table = "card_special_colors"
	// CardsTable is the table that holds the cards relation/edge.
	CardsTable = "cards"
	// CardsInverseTable is the table name for the Card entity.
	// It exists in this package in order to avoid circular dependency with the "card" package.
	CardsInverseTable = "cards"
	// CardsColumn is the table column denoting the cards relation/edge.
	CardsColumn = "card_special_color_id"
)

Variables

Columns holds all SQL columns for cardspecialcolor fields.

var (
	// KeyValidator is a validator for the "key" field. It is called by the builders before save.
	KeyValidator func(string) error
)

Functions

func And

And groups predicates with the AND operator between them.

func HasCards

func HasCards() predicate.CardSpecialColor

HasCards applies the HasEdge predicate on the "cards" edge.

func HasCardsWith

func HasCardsWith(preds ...predicate.Card) predicate.CardSpecialColor

HasCardsWith applies the HasEdge predicate on the "cards" edge with a given conditions (other predicates).

func ID

ID filters vertices based on their ID field.

func IDEQ

IDEQ applies the EQ predicate on the ID field.

func IDGT

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id int) predicate.CardSpecialColor

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...int) predicate.CardSpecialColor

IDIn applies the In predicate on the ID field.

func IDLT

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id int) predicate.CardSpecialColor

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id int) predicate.CardSpecialColor

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...int) predicate.CardSpecialColor

IDNotIn applies the NotIn predicate on the ID field.

func Key

Key applies equality check predicate on the "key" field. It's identical to KeyEQ.

func KeyContains

func KeyContains(v string) predicate.CardSpecialColor

KeyContains applies the Contains predicate on the "key" field.

func KeyContainsFold

func KeyContainsFold(v string) predicate.CardSpecialColor

KeyContainsFold applies the ContainsFold predicate on the "key" field.

func KeyEQ

KeyEQ applies the EQ predicate on the "key" field.

func KeyEqualFold

func KeyEqualFold(v string) predicate.CardSpecialColor

KeyEqualFold applies the EqualFold predicate on the "key" field.

func KeyGT

KeyGT applies the GT predicate on the "key" field.

func KeyGTE

KeyGTE applies the GTE predicate on the "key" field.

func KeyHasPrefix

func KeyHasPrefix(v string) predicate.CardSpecialColor

KeyHasPrefix applies the HasPrefix predicate on the "key" field.

func KeyHasSuffix

func KeyHasSuffix(v string) predicate.CardSpecialColor

KeyHasSuffix applies the HasSuffix predicate on the "key" field.

func KeyIn

func KeyIn(vs ...string) predicate.CardSpecialColor

KeyIn applies the In predicate on the "key" field.

func KeyLT

KeyLT applies the LT predicate on the "key" field.

func KeyLTE

KeyLTE applies the LTE predicate on the "key" field.

func KeyNEQ

KeyNEQ applies the NEQ predicate on the "key" field.

func KeyNotIn

func KeyNotIn(vs ...string) predicate.CardSpecialColor

KeyNotIn applies the NotIn predicate on the "key" field.

func NameEn

NameEn applies equality check predicate on the "name_en" field. It's identical to NameEnEQ.

func NameEnContains

func NameEnContains(v string) predicate.CardSpecialColor

NameEnContains applies the Contains predicate on the "name_en" field.

func NameEnContainsFold

func NameEnContainsFold(v string) predicate.CardSpecialColor

NameEnContainsFold applies the ContainsFold predicate on the "name_en" field.

func NameEnEQ

func NameEnEQ(v string) predicate.CardSpecialColor

NameEnEQ applies the EQ predicate on the "name_en" field.

func NameEnEqualFold

func NameEnEqualFold(v string) predicate.CardSpecialColor

NameEnEqualFold applies the EqualFold predicate on the "name_en" field.

func NameEnGT

func NameEnGT(v string) predicate.CardSpecialColor

NameEnGT applies the GT predicate on the "name_en" field.

func NameEnGTE

func NameEnGTE(v string) predicate.CardSpecialColor

NameEnGTE applies the GTE predicate on the "name_en" field.

func NameEnHasPrefix

func NameEnHasPrefix(v string) predicate.CardSpecialColor

NameEnHasPrefix applies the HasPrefix predicate on the "name_en" field.

func NameEnHasSuffix

func NameEnHasSuffix(v string) predicate.CardSpecialColor

NameEnHasSuffix applies the HasSuffix predicate on the "name_en" field.

func NameEnIn

func NameEnIn(vs ...string) predicate.CardSpecialColor

NameEnIn applies the In predicate on the "name_en" field.

func NameEnIsNil

func NameEnIsNil() predicate.CardSpecialColor

NameEnIsNil applies the IsNil predicate on the "name_en" field.

func NameEnLT

func NameEnLT(v string) predicate.CardSpecialColor

NameEnLT applies the LT predicate on the "name_en" field.

func NameEnLTE

func NameEnLTE(v string) predicate.CardSpecialColor

NameEnLTE applies the LTE predicate on the "name_en" field.

func NameEnNEQ

func NameEnNEQ(v string) predicate.CardSpecialColor

NameEnNEQ applies the NEQ predicate on the "name_en" field.

func NameEnNotIn

func NameEnNotIn(vs ...string) predicate.CardSpecialColor

NameEnNotIn applies the NotIn predicate on the "name_en" field.

func NameEnNotNil

func NameEnNotNil() predicate.CardSpecialColor

NameEnNotNil applies the NotNil predicate on the "name_en" field.

func NameJa

NameJa applies equality check predicate on the "name_ja" field. It's identical to NameJaEQ.

func NameJaContains

func NameJaContains(v string) predicate.CardSpecialColor

NameJaContains applies the Contains predicate on the "name_ja" field.

func NameJaContainsFold

func NameJaContainsFold(v string) predicate.CardSpecialColor

NameJaContainsFold applies the ContainsFold predicate on the "name_ja" field.

func NameJaEQ

func NameJaEQ(v string) predicate.CardSpecialColor

NameJaEQ applies the EQ predicate on the "name_ja" field.

func NameJaEqualFold

func NameJaEqualFold(v string) predicate.CardSpecialColor

NameJaEqualFold applies the EqualFold predicate on the "name_ja" field.

func NameJaGT

func NameJaGT(v string) predicate.CardSpecialColor

NameJaGT applies the GT predicate on the "name_ja" field.

func NameJaGTE

func NameJaGTE(v string) predicate.CardSpecialColor

NameJaGTE applies the GTE predicate on the "name_ja" field.

func NameJaHasPrefix

func NameJaHasPrefix(v string) predicate.CardSpecialColor

NameJaHasPrefix applies the HasPrefix predicate on the "name_ja" field.

func NameJaHasSuffix

func NameJaHasSuffix(v string) predicate.CardSpecialColor

NameJaHasSuffix applies the HasSuffix predicate on the "name_ja" field.

func NameJaIn

func NameJaIn(vs ...string) predicate.CardSpecialColor

NameJaIn applies the In predicate on the "name_ja" field.

func NameJaIsNil

func NameJaIsNil() predicate.CardSpecialColor

NameJaIsNil applies the IsNil predicate on the "name_ja" field.

func NameJaLT

func NameJaLT(v string) predicate.CardSpecialColor

NameJaLT applies the LT predicate on the "name_ja" field.

func NameJaLTE

func NameJaLTE(v string) predicate.CardSpecialColor

NameJaLTE applies the LTE predicate on the "name_ja" field.

func NameJaNEQ

func NameJaNEQ(v string) predicate.CardSpecialColor

NameJaNEQ applies the NEQ predicate on the "name_ja" field.

func NameJaNotIn

func NameJaNotIn(vs ...string) predicate.CardSpecialColor

NameJaNotIn applies the NotIn predicate on the "name_ja" field.

func NameJaNotNil

func NameJaNotNil() predicate.CardSpecialColor

NameJaNotNil applies the NotNil predicate on the "name_ja" field.

func Not

Not applies the not operator on the given predicate.

func Or

Or groups predicates with the OR operator between them.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the CardSpecialColor queries.

func ByCards

func ByCards(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByCards orders the results by cards terms.

func ByCardsCount

func ByCardsCount(opts ...sql.OrderTermOption) OrderOption

ByCardsCount orders the results by cards count.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByKey

func ByKey(opts ...sql.OrderTermOption) OrderOption

ByKey orders the results by the key field.

func ByNameEn

func ByNameEn(opts ...sql.OrderTermOption) OrderOption

ByNameEn orders the results by the name_en field.

func ByNameJa

func ByNameJa(opts ...sql.OrderTermOption) OrderOption

ByNameJa orders the results by the name_ja field.

Jump to