Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.CardSpecialColor) predicate.CardSpecialColor
- func HasCards() predicate.CardSpecialColor
- func HasCardsWith(preds ...predicate.Card) predicate.CardSpecialColor
- func ID(id int) predicate.CardSpecialColor
- func IDEQ(id int) predicate.CardSpecialColor
- func IDGT(id int) predicate.CardSpecialColor
- func IDGTE(id int) predicate.CardSpecialColor
- func IDIn(ids ...int) predicate.CardSpecialColor
- func IDLT(id int) predicate.CardSpecialColor
- func IDLTE(id int) predicate.CardSpecialColor
- func IDNEQ(id int) predicate.CardSpecialColor
- func IDNotIn(ids ...int) predicate.CardSpecialColor
- func Key(v string) predicate.CardSpecialColor
- func KeyContains(v string) predicate.CardSpecialColor
- func KeyContainsFold(v string) predicate.CardSpecialColor
- func KeyEQ(v string) predicate.CardSpecialColor
- func KeyEqualFold(v string) predicate.CardSpecialColor
- func KeyGT(v string) predicate.CardSpecialColor
- func KeyGTE(v string) predicate.CardSpecialColor
- func KeyHasPrefix(v string) predicate.CardSpecialColor
- func KeyHasSuffix(v string) predicate.CardSpecialColor
- func KeyIn(vs ...string) predicate.CardSpecialColor
- func KeyLT(v string) predicate.CardSpecialColor
- func KeyLTE(v string) predicate.CardSpecialColor
- func KeyNEQ(v string) predicate.CardSpecialColor
- func KeyNotIn(vs ...string) predicate.CardSpecialColor
- func NameEn(v string) predicate.CardSpecialColor
- func NameEnContains(v string) predicate.CardSpecialColor
- func NameEnContainsFold(v string) predicate.CardSpecialColor
- func NameEnEQ(v string) predicate.CardSpecialColor
- func NameEnEqualFold(v string) predicate.CardSpecialColor
- func NameEnGT(v string) predicate.CardSpecialColor
- func NameEnGTE(v string) predicate.CardSpecialColor
- func NameEnHasPrefix(v string) predicate.CardSpecialColor
- func NameEnHasSuffix(v string) predicate.CardSpecialColor
- func NameEnIn(vs ...string) predicate.CardSpecialColor
- func NameEnIsNil() predicate.CardSpecialColor
- func NameEnLT(v string) predicate.CardSpecialColor
- func NameEnLTE(v string) predicate.CardSpecialColor
- func NameEnNEQ(v string) predicate.CardSpecialColor
- func NameEnNotIn(vs ...string) predicate.CardSpecialColor
- func NameEnNotNil() predicate.CardSpecialColor
- func NameJa(v string) predicate.CardSpecialColor
- func NameJaContains(v string) predicate.CardSpecialColor
- func NameJaContainsFold(v string) predicate.CardSpecialColor
- func NameJaEQ(v string) predicate.CardSpecialColor
- func NameJaEqualFold(v string) predicate.CardSpecialColor
- func NameJaGT(v string) predicate.CardSpecialColor
- func NameJaGTE(v string) predicate.CardSpecialColor
- func NameJaHasPrefix(v string) predicate.CardSpecialColor
- func NameJaHasSuffix(v string) predicate.CardSpecialColor
- func NameJaIn(vs ...string) predicate.CardSpecialColor
- func NameJaIsNil() predicate.CardSpecialColor
- func NameJaLT(v string) predicate.CardSpecialColor
- func NameJaLTE(v string) predicate.CardSpecialColor
- func NameJaNEQ(v string) predicate.CardSpecialColor
- func NameJaNotIn(vs ...string) predicate.CardSpecialColor
- func NameJaNotNil() predicate.CardSpecialColor
- func Not(p predicate.CardSpecialColor) predicate.CardSpecialColor
- func Or(predicates ...predicate.CardSpecialColor) predicate.CardSpecialColor
- func ValidColumn(column string) bool
- type OrderOption
- func ByCards(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByCardsCount(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByKey(opts ...sql.OrderTermOption) OrderOption
- func ByNameEn(opts ...sql.OrderTermOption) OrderOption
- func ByNameJa(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the cardspecialcolor type in the database. Label = "card_special_color" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldKey holds the string denoting the key field in the database. FieldKey = "key" // FieldNameJa holds the string denoting the name_ja field in the database. FieldNameJa = "name_ja" // FieldNameEn holds the string denoting the name_en field in the database. FieldNameEn = "name_en" // EdgeCards holds the string denoting the cards edge name in mutations. EdgeCards = "cards" // Table holds the table name of the cardspecialcolor in the database. Table = "card_special_colors" // CardsTable is the table that holds the cards relation/edge. CardsTable = "cards" // CardsInverseTable is the table name for the Card entity. // It exists in this package in order to avoid circular dependency with the "card" package. CardsInverseTable = "cards" // CardsColumn is the table column denoting the cards relation/edge. CardsColumn = "card_special_color_id" )
Variables ¶
var Columns = []string{ FieldID, FieldKey, FieldNameJa, FieldNameEn, }
Columns holds all SQL columns for cardspecialcolor fields.
var ( // KeyValidator is a validator for the "key" field. It is called by the builders before save. KeyValidator func(string) error )
Functions ¶
func And ¶
func And(predicates ...predicate.CardSpecialColor) predicate.CardSpecialColor
And groups predicates with the AND operator between them.
func HasCards ¶
func HasCards() predicate.CardSpecialColor
HasCards applies the HasEdge predicate on the "cards" edge.
func HasCardsWith ¶
func HasCardsWith(preds ...predicate.Card) predicate.CardSpecialColor
HasCardsWith applies the HasEdge predicate on the "cards" edge with a given conditions (other predicates).
func IDEQ ¶
func IDEQ(id int) predicate.CardSpecialColor
IDEQ applies the EQ predicate on the ID field.
func IDGT ¶
func IDGT(id int) predicate.CardSpecialColor
IDGT applies the GT predicate on the ID field.
func IDGTE ¶
func IDGTE(id int) predicate.CardSpecialColor
IDGTE applies the GTE predicate on the ID field.
func IDIn ¶
func IDIn(ids ...int) predicate.CardSpecialColor
IDIn applies the In predicate on the ID field.
func IDLT ¶
func IDLT(id int) predicate.CardSpecialColor
IDLT applies the LT predicate on the ID field.
func IDLTE ¶
func IDLTE(id int) predicate.CardSpecialColor
IDLTE applies the LTE predicate on the ID field.
func IDNEQ ¶
func IDNEQ(id int) predicate.CardSpecialColor
IDNEQ applies the NEQ predicate on the ID field.
func IDNotIn ¶
func IDNotIn(ids ...int) predicate.CardSpecialColor
IDNotIn applies the NotIn predicate on the ID field.
func Key ¶
func Key(v string) predicate.CardSpecialColor
Key applies equality check predicate on the "key" field. It's identical to KeyEQ.
func KeyContains ¶
func KeyContains(v string) predicate.CardSpecialColor
KeyContains applies the Contains predicate on the "key" field.
func KeyContainsFold ¶
func KeyContainsFold(v string) predicate.CardSpecialColor
KeyContainsFold applies the ContainsFold predicate on the "key" field.
func KeyEQ ¶
func KeyEQ(v string) predicate.CardSpecialColor
KeyEQ applies the EQ predicate on the "key" field.
func KeyEqualFold ¶
func KeyEqualFold(v string) predicate.CardSpecialColor
KeyEqualFold applies the EqualFold predicate on the "key" field.
func KeyGT ¶
func KeyGT(v string) predicate.CardSpecialColor
KeyGT applies the GT predicate on the "key" field.
func KeyGTE ¶
func KeyGTE(v string) predicate.CardSpecialColor
KeyGTE applies the GTE predicate on the "key" field.
func KeyHasPrefix ¶
func KeyHasPrefix(v string) predicate.CardSpecialColor
KeyHasPrefix applies the HasPrefix predicate on the "key" field.
func KeyHasSuffix ¶
func KeyHasSuffix(v string) predicate.CardSpecialColor
KeyHasSuffix applies the HasSuffix predicate on the "key" field.
func KeyIn ¶
func KeyIn(vs ...string) predicate.CardSpecialColor
KeyIn applies the In predicate on the "key" field.
func KeyLT ¶
func KeyLT(v string) predicate.CardSpecialColor
KeyLT applies the LT predicate on the "key" field.
func KeyLTE ¶
func KeyLTE(v string) predicate.CardSpecialColor
KeyLTE applies the LTE predicate on the "key" field.
func KeyNEQ ¶
func KeyNEQ(v string) predicate.CardSpecialColor
KeyNEQ applies the NEQ predicate on the "key" field.
func KeyNotIn ¶
func KeyNotIn(vs ...string) predicate.CardSpecialColor
KeyNotIn applies the NotIn predicate on the "key" field.
func NameEn ¶
func NameEn(v string) predicate.CardSpecialColor
NameEn applies equality check predicate on the "name_en" field. It's identical to NameEnEQ.
func NameEnContains ¶
func NameEnContains(v string) predicate.CardSpecialColor
NameEnContains applies the Contains predicate on the "name_en" field.
func NameEnContainsFold ¶
func NameEnContainsFold(v string) predicate.CardSpecialColor
NameEnContainsFold applies the ContainsFold predicate on the "name_en" field.
func NameEnEQ ¶
func NameEnEQ(v string) predicate.CardSpecialColor
NameEnEQ applies the EQ predicate on the "name_en" field.
func NameEnEqualFold ¶
func NameEnEqualFold(v string) predicate.CardSpecialColor
NameEnEqualFold applies the EqualFold predicate on the "name_en" field.
func NameEnGT ¶
func NameEnGT(v string) predicate.CardSpecialColor
NameEnGT applies the GT predicate on the "name_en" field.
func NameEnGTE ¶
func NameEnGTE(v string) predicate.CardSpecialColor
NameEnGTE applies the GTE predicate on the "name_en" field.
func NameEnHasPrefix ¶
func NameEnHasPrefix(v string) predicate.CardSpecialColor
NameEnHasPrefix applies the HasPrefix predicate on the "name_en" field.
func NameEnHasSuffix ¶
func NameEnHasSuffix(v string) predicate.CardSpecialColor
NameEnHasSuffix applies the HasSuffix predicate on the "name_en" field.
func NameEnIn ¶
func NameEnIn(vs ...string) predicate.CardSpecialColor
NameEnIn applies the In predicate on the "name_en" field.
func NameEnIsNil ¶
func NameEnIsNil() predicate.CardSpecialColor
NameEnIsNil applies the IsNil predicate on the "name_en" field.
func NameEnLT ¶
func NameEnLT(v string) predicate.CardSpecialColor
NameEnLT applies the LT predicate on the "name_en" field.
func NameEnLTE ¶
func NameEnLTE(v string) predicate.CardSpecialColor
NameEnLTE applies the LTE predicate on the "name_en" field.
func NameEnNEQ ¶
func NameEnNEQ(v string) predicate.CardSpecialColor
NameEnNEQ applies the NEQ predicate on the "name_en" field.
func NameEnNotIn ¶
func NameEnNotIn(vs ...string) predicate.CardSpecialColor
NameEnNotIn applies the NotIn predicate on the "name_en" field.
func NameEnNotNil ¶
func NameEnNotNil() predicate.CardSpecialColor
NameEnNotNil applies the NotNil predicate on the "name_en" field.
func NameJa ¶
func NameJa(v string) predicate.CardSpecialColor
NameJa applies equality check predicate on the "name_ja" field. It's identical to NameJaEQ.
func NameJaContains ¶
func NameJaContains(v string) predicate.CardSpecialColor
NameJaContains applies the Contains predicate on the "name_ja" field.
func NameJaContainsFold ¶
func NameJaContainsFold(v string) predicate.CardSpecialColor
NameJaContainsFold applies the ContainsFold predicate on the "name_ja" field.
func NameJaEQ ¶
func NameJaEQ(v string) predicate.CardSpecialColor
NameJaEQ applies the EQ predicate on the "name_ja" field.
func NameJaEqualFold ¶
func NameJaEqualFold(v string) predicate.CardSpecialColor
NameJaEqualFold applies the EqualFold predicate on the "name_ja" field.
func NameJaGT ¶
func NameJaGT(v string) predicate.CardSpecialColor
NameJaGT applies the GT predicate on the "name_ja" field.
func NameJaGTE ¶
func NameJaGTE(v string) predicate.CardSpecialColor
NameJaGTE applies the GTE predicate on the "name_ja" field.
func NameJaHasPrefix ¶
func NameJaHasPrefix(v string) predicate.CardSpecialColor
NameJaHasPrefix applies the HasPrefix predicate on the "name_ja" field.
func NameJaHasSuffix ¶
func NameJaHasSuffix(v string) predicate.CardSpecialColor
NameJaHasSuffix applies the HasSuffix predicate on the "name_ja" field.
func NameJaIn ¶
func NameJaIn(vs ...string) predicate.CardSpecialColor
NameJaIn applies the In predicate on the "name_ja" field.
func NameJaIsNil ¶
func NameJaIsNil() predicate.CardSpecialColor
NameJaIsNil applies the IsNil predicate on the "name_ja" field.
func NameJaLT ¶
func NameJaLT(v string) predicate.CardSpecialColor
NameJaLT applies the LT predicate on the "name_ja" field.
func NameJaLTE ¶
func NameJaLTE(v string) predicate.CardSpecialColor
NameJaLTE applies the LTE predicate on the "name_ja" field.
func NameJaNEQ ¶
func NameJaNEQ(v string) predicate.CardSpecialColor
NameJaNEQ applies the NEQ predicate on the "name_ja" field.
func NameJaNotIn ¶
func NameJaNotIn(vs ...string) predicate.CardSpecialColor
NameJaNotIn applies the NotIn predicate on the "name_ja" field.
func NameJaNotNil ¶
func NameJaNotNil() predicate.CardSpecialColor
NameJaNotNil applies the NotNil predicate on the "name_ja" field.
func Not ¶
func Not(p predicate.CardSpecialColor) predicate.CardSpecialColor
Not applies the not operator on the given predicate.
func Or ¶
func Or(predicates ...predicate.CardSpecialColor) predicate.CardSpecialColor
Or groups predicates with the OR operator between them.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the CardSpecialColor queries.
func ByCards ¶
func ByCards(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByCards orders the results by cards terms.
func ByCardsCount ¶
func ByCardsCount(opts ...sql.OrderTermOption) OrderOption
ByCardsCount orders the results by cards count.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByKey ¶
func ByKey(opts ...sql.OrderTermOption) OrderOption
ByKey orders the results by the key field.
func ByNameEn ¶
func ByNameEn(opts ...sql.OrderTermOption) OrderOption
ByNameEn orders the results by the name_en field.
func ByNameJa ¶
func ByNameJa(opts ...sql.OrderTermOption) OrderOption
ByNameJa orders the results by the name_ja field.